# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['InstanceArgs', 'Instance']

@pulumi.input_type
class InstanceArgs:
    def __init__(__self__, *,
                 charge_detail: pulumi.Input['InstanceChargeDetailArgs'],
                 db_engine_version: pulumi.Input[builtins.str],
                 nodes: pulumi.Input[Sequence[pulumi.Input['InstanceNodeArgs']]],
                 storage_space: pulumi.Input[builtins.int],
                 storage_type: pulumi.Input[builtins.str],
                 subnet_id: pulumi.Input[builtins.str],
                 vpc_id: pulumi.Input[builtins.str],
                 allow_list_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 auto_storage_scaling_config: Optional[pulumi.Input['InstanceAutoStorageScalingConfigArgs']] = None,
                 auto_upgrade_minor_version: Optional[pulumi.Input[builtins.str]] = None,
                 cpu_num: Optional[pulumi.Input[builtins.int]] = None,
                 db_param_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 db_time_zone: Optional[pulumi.Input[builtins.str]] = None,
                 deletion_protection: Optional[pulumi.Input[builtins.str]] = None,
                 global_read_only: Optional[pulumi.Input[builtins.bool]] = None,
                 instance_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type: Optional[pulumi.Input[builtins.str]] = None,
                 lower_case_table_names: Optional[pulumi.Input[builtins.str]] = None,
                 maintenance_window: Optional[pulumi.Input['InstanceMaintenanceWindowArgs']] = None,
                 node_spec: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 super_account_name: Optional[pulumi.Input[builtins.str]] = None,
                 super_account_password: Optional[pulumi.Input[builtins.str]] = None,
                 sync_mode: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]] = None):
        """
        The set of arguments for constructing a Instance resource.
        :param pulumi.Input['InstanceChargeDetailArgs'] charge_detail: 付费方式。
        :param pulumi.Input[builtins.str] db_engine_version: 兼容版本。取值：MySQL*5*7：MySQL 5.7 版本。MySQL*8*0：MySQL 8.0 版本。
        :param pulumi.Input[builtins.int] storage_space: 实例总存储空间。单位为 GB。
        :param pulumi.Input[builtins.str] storage_type: 实例的存储类型。取值范围：LocalSSD：本地盘。CloudESSD*FlexPL：FlexPL 云盘。CloudESSD*PL0：PL0 云盘。
        :param pulumi.Input[builtins.str] subnet_id: 子网 ID。
        :param pulumi.Input[builtins.str] vpc_id: 专有网络（VPC） ID。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allow_list_ids: 白名单 ID。如需绑定多个白名单，白名单 ID 用英文逗号（,）分隔。一个实例最多可绑定 100 个白名单。
        :param pulumi.Input['InstanceAutoStorageScalingConfigArgs'] auto_storage_scaling_config: 自动扩容配置。
        :param pulumi.Input[builtins.str] auto_upgrade_minor_version: 实例内核小版本的升级策略。取值：Auto：自动升级。Manual：手动升级。
        :param pulumi.Input[builtins.int] cpu_num: 实例数据库代理服务的 CPU 核数。
        :param pulumi.Input[builtins.str] db_param_group_id: 参数模板 ID。默认值为数据库引擎版本对应的默认参数模板。
        :param pulumi.Input[builtins.str] db_time_zone: 时区。支持 UTC -12:00 ~ +13:00。默认值为 Region 所在的 TimeZone。
        :param pulumi.Input[builtins.str] deletion_protection: 是否启用实例的删除保护功能。取值：Enabled：是。Disabled：否。默认值。
        :param pulumi.Input[builtins.bool] global_read_only: 是否开启全局只读。取值：true：是。false：否。默认值为 false。
        :param pulumi.Input[builtins.str] instance_name: 实例名称。
        :param pulumi.Input[builtins.str] instance_type: 实例类型。取值：DoubleNode，双节点类型。MultiNode，多节点类型。
        :param pulumi.Input[builtins.str] lower_case_table_names: 表名是否区分大小写，默认取值为 true。取值：false：表名被存储成固定且表名称大小写敏感。true：表名将被存储成小写且表名称大小写不敏感。
        :param pulumi.Input['InstanceMaintenanceWindowArgs'] maintenance_window: 在创建实例时指定实例的可维护时间段。该字段为可选，不设置时默认为一周内每一天的 UTC18:00Z-21:59Z（即北京时间 02:00-05:59）。
        :param pulumi.Input[builtins.str] node_spec: 节点规格。
        :param pulumi.Input[builtins.int] port: 默认终端的私网端口。端口号的取值范围为 1000~65534，默认值为 3306。创建新的连接终端或开启新地址时，将使用默认终端的私网端口实时配置为默认端口。
        :param pulumi.Input[builtins.str] project_name: 所属项目。
        :param pulumi.Input[builtins.str] super_account_name: 高权限账号名称。不传此参数默认不创建高权限账号。
        :param pulumi.Input[builtins.str] super_account_password: 高权限账号的密码。密码规则如下：长度为 8~32 个字符。由大写字母、小写字母、数字、特殊字符中的至少三种组成。特殊字符为 !@#$%^&*()_+-=,.&?|/。
        :param pulumi.Input[builtins.str] sync_mode: 数据同步方式：SemiSync：半同步。Async：异步。
        """
        pulumi.set(__self__, "charge_detail", charge_detail)
        pulumi.set(__self__, "db_engine_version", db_engine_version)
        pulumi.set(__self__, "nodes", nodes)
        pulumi.set(__self__, "storage_space", storage_space)
        pulumi.set(__self__, "storage_type", storage_type)
        pulumi.set(__self__, "subnet_id", subnet_id)
        pulumi.set(__self__, "vpc_id", vpc_id)
        if allow_list_ids is not None:
            pulumi.set(__self__, "allow_list_ids", allow_list_ids)
        if auto_storage_scaling_config is not None:
            pulumi.set(__self__, "auto_storage_scaling_config", auto_storage_scaling_config)
        if auto_upgrade_minor_version is not None:
            pulumi.set(__self__, "auto_upgrade_minor_version", auto_upgrade_minor_version)
        if cpu_num is not None:
            pulumi.set(__self__, "cpu_num", cpu_num)
        if db_param_group_id is not None:
            pulumi.set(__self__, "db_param_group_id", db_param_group_id)
        if db_time_zone is not None:
            pulumi.set(__self__, "db_time_zone", db_time_zone)
        if deletion_protection is not None:
            pulumi.set(__self__, "deletion_protection", deletion_protection)
        if global_read_only is not None:
            pulumi.set(__self__, "global_read_only", global_read_only)
        if instance_name is not None:
            pulumi.set(__self__, "instance_name", instance_name)
        if instance_type is not None:
            pulumi.set(__self__, "instance_type", instance_type)
        if lower_case_table_names is not None:
            pulumi.set(__self__, "lower_case_table_names", lower_case_table_names)
        if maintenance_window is not None:
            pulumi.set(__self__, "maintenance_window", maintenance_window)
        if node_spec is not None:
            pulumi.set(__self__, "node_spec", node_spec)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if super_account_name is not None:
            pulumi.set(__self__, "super_account_name", super_account_name)
        if super_account_password is not None:
            pulumi.set(__self__, "super_account_password", super_account_password)
        if sync_mode is not None:
            pulumi.set(__self__, "sync_mode", sync_mode)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="chargeDetail")
    def charge_detail(self) -> pulumi.Input['InstanceChargeDetailArgs']:
        """
        付费方式。
        """
        return pulumi.get(self, "charge_detail")

    @charge_detail.setter
    def charge_detail(self, value: pulumi.Input['InstanceChargeDetailArgs']):
        pulumi.set(self, "charge_detail", value)

    @property
    @pulumi.getter(name="dbEngineVersion")
    def db_engine_version(self) -> pulumi.Input[builtins.str]:
        """
        兼容版本。取值：MySQL*5*7：MySQL 5.7 版本。MySQL*8*0：MySQL 8.0 版本。
        """
        return pulumi.get(self, "db_engine_version")

    @db_engine_version.setter
    def db_engine_version(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "db_engine_version", value)

    @property
    @pulumi.getter
    def nodes(self) -> pulumi.Input[Sequence[pulumi.Input['InstanceNodeArgs']]]:
        return pulumi.get(self, "nodes")

    @nodes.setter
    def nodes(self, value: pulumi.Input[Sequence[pulumi.Input['InstanceNodeArgs']]]):
        pulumi.set(self, "nodes", value)

    @property
    @pulumi.getter(name="storageSpace")
    def storage_space(self) -> pulumi.Input[builtins.int]:
        """
        实例总存储空间。单位为 GB。
        """
        return pulumi.get(self, "storage_space")

    @storage_space.setter
    def storage_space(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "storage_space", value)

    @property
    @pulumi.getter(name="storageType")
    def storage_type(self) -> pulumi.Input[builtins.str]:
        """
        实例的存储类型。取值范围：LocalSSD：本地盘。CloudESSD*FlexPL：FlexPL 云盘。CloudESSD*PL0：PL0 云盘。
        """
        return pulumi.get(self, "storage_type")

    @storage_type.setter
    def storage_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "storage_type", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Input[builtins.str]:
        """
        子网 ID。
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "subnet_id", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[builtins.str]:
        """
        专有网络（VPC） ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="allowListIds")
    def allow_list_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        白名单 ID。如需绑定多个白名单，白名单 ID 用英文逗号（,）分隔。一个实例最多可绑定 100 个白名单。
        """
        return pulumi.get(self, "allow_list_ids")

    @allow_list_ids.setter
    def allow_list_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "allow_list_ids", value)

    @property
    @pulumi.getter(name="autoStorageScalingConfig")
    def auto_storage_scaling_config(self) -> Optional[pulumi.Input['InstanceAutoStorageScalingConfigArgs']]:
        """
        自动扩容配置。
        """
        return pulumi.get(self, "auto_storage_scaling_config")

    @auto_storage_scaling_config.setter
    def auto_storage_scaling_config(self, value: Optional[pulumi.Input['InstanceAutoStorageScalingConfigArgs']]):
        pulumi.set(self, "auto_storage_scaling_config", value)

    @property
    @pulumi.getter(name="autoUpgradeMinorVersion")
    def auto_upgrade_minor_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例内核小版本的升级策略。取值：Auto：自动升级。Manual：手动升级。
        """
        return pulumi.get(self, "auto_upgrade_minor_version")

    @auto_upgrade_minor_version.setter
    def auto_upgrade_minor_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "auto_upgrade_minor_version", value)

    @property
    @pulumi.getter(name="cpuNum")
    def cpu_num(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        实例数据库代理服务的 CPU 核数。
        """
        return pulumi.get(self, "cpu_num")

    @cpu_num.setter
    def cpu_num(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "cpu_num", value)

    @property
    @pulumi.getter(name="dbParamGroupId")
    def db_param_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        参数模板 ID。默认值为数据库引擎版本对应的默认参数模板。
        """
        return pulumi.get(self, "db_param_group_id")

    @db_param_group_id.setter
    def db_param_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "db_param_group_id", value)

    @property
    @pulumi.getter(name="dbTimeZone")
    def db_time_zone(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        时区。支持 UTC -12:00 ~ +13:00。默认值为 Region 所在的 TimeZone。
        """
        return pulumi.get(self, "db_time_zone")

    @db_time_zone.setter
    def db_time_zone(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "db_time_zone", value)

    @property
    @pulumi.getter(name="deletionProtection")
    def deletion_protection(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        是否启用实例的删除保护功能。取值：Enabled：是。Disabled：否。默认值。
        """
        return pulumi.get(self, "deletion_protection")

    @deletion_protection.setter
    def deletion_protection(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "deletion_protection", value)

    @property
    @pulumi.getter(name="globalReadOnly")
    def global_read_only(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启全局只读。取值：true：是。false：否。默认值为 false。
        """
        return pulumi.get(self, "global_read_only")

    @global_read_only.setter
    def global_read_only(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "global_read_only", value)

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例名称。
        """
        return pulumi.get(self, "instance_name")

    @instance_name.setter
    def instance_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_name", value)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例类型。取值：DoubleNode，双节点类型。MultiNode，多节点类型。
        """
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_type", value)

    @property
    @pulumi.getter(name="lowerCaseTableNames")
    def lower_case_table_names(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        表名是否区分大小写，默认取值为 true。取值：false：表名被存储成固定且表名称大小写敏感。true：表名将被存储成小写且表名称大小写不敏感。
        """
        return pulumi.get(self, "lower_case_table_names")

    @lower_case_table_names.setter
    def lower_case_table_names(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "lower_case_table_names", value)

    @property
    @pulumi.getter(name="maintenanceWindow")
    def maintenance_window(self) -> Optional[pulumi.Input['InstanceMaintenanceWindowArgs']]:
        """
        在创建实例时指定实例的可维护时间段。该字段为可选，不设置时默认为一周内每一天的 UTC18:00Z-21:59Z（即北京时间 02:00-05:59）。
        """
        return pulumi.get(self, "maintenance_window")

    @maintenance_window.setter
    def maintenance_window(self, value: Optional[pulumi.Input['InstanceMaintenanceWindowArgs']]):
        pulumi.set(self, "maintenance_window", value)

    @property
    @pulumi.getter(name="nodeSpec")
    def node_spec(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        节点规格。
        """
        return pulumi.get(self, "node_spec")

    @node_spec.setter
    def node_spec(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "node_spec", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        默认终端的私网端口。端口号的取值范围为 1000~65534，默认值为 3306。创建新的连接终端或开启新地址时，将使用默认终端的私网端口实时配置为默认端口。
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        所属项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="superAccountName")
    def super_account_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        高权限账号名称。不传此参数默认不创建高权限账号。
        """
        return pulumi.get(self, "super_account_name")

    @super_account_name.setter
    def super_account_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "super_account_name", value)

    @property
    @pulumi.getter(name="superAccountPassword")
    def super_account_password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        高权限账号的密码。密码规则如下：长度为 8~32 个字符。由大写字母、小写字母、数字、特殊字符中的至少三种组成。特殊字符为 !@#$%^&*()_+-=,.&?|/。
        """
        return pulumi.get(self, "super_account_password")

    @super_account_password.setter
    def super_account_password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "super_account_password", value)

    @property
    @pulumi.getter(name="syncMode")
    def sync_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        数据同步方式：SemiSync：半同步。Async：异步。
        """
        return pulumi.get(self, "sync_mode")

    @sync_mode.setter
    def sync_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "sync_mode", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _InstanceState:
    def __init__(__self__, *,
                 address_objects: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceAddressObjectArgs']]]] = None,
                 allow_list_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 allow_list_version: Optional[pulumi.Input[builtins.str]] = None,
                 auto_storage_scaling_config: Optional[pulumi.Input['InstanceAutoStorageScalingConfigArgs']] = None,
                 auto_upgrade_minor_version: Optional[pulumi.Input[builtins.str]] = None,
                 backup_audit_log_size: Optional[pulumi.Input[builtins.int]] = None,
                 backup_bin_log_size: Optional[pulumi.Input[builtins.int]] = None,
                 backup_data_size: Optional[pulumi.Input[builtins.int]] = None,
                 backup_error_log_size: Optional[pulumi.Input[builtins.int]] = None,
                 backup_free_quota_size: Optional[pulumi.Input[builtins.int]] = None,
                 backup_log_size: Optional[pulumi.Input[builtins.int]] = None,
                 backup_slow_log_size: Optional[pulumi.Input[builtins.int]] = None,
                 backup_use: Optional[pulumi.Input[builtins.float]] = None,
                 basic_backup_binlog_size: Optional[pulumi.Input[builtins.int]] = None,
                 basic_backup_data_size: Optional[pulumi.Input[builtins.int]] = None,
                 charge_detail: Optional[pulumi.Input['InstanceChargeDetailArgs']] = None,
                 cpu_num: Optional[pulumi.Input[builtins.int]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 current_kernel_version: Optional[pulumi.Input[builtins.str]] = None,
                 db_engine_version: Optional[pulumi.Input[builtins.str]] = None,
                 db_param_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 db_time_zone: Optional[pulumi.Input[builtins.str]] = None,
                 deletion_protection: Optional[pulumi.Input[builtins.str]] = None,
                 disaster_recovery_instances: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceDisasterRecoveryInstanceArgs']]]] = None,
                 dr_dts_task_id: Optional[pulumi.Input[builtins.str]] = None,
                 dr_dts_task_name: Optional[pulumi.Input[builtins.str]] = None,
                 dr_dts_task_status: Optional[pulumi.Input[builtins.str]] = None,
                 dr_seconds_behind_master: Optional[pulumi.Input[builtins.int]] = None,
                 endpoints: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceEndpointArgs']]]] = None,
                 global_read_only: Optional[pulumi.Input[builtins.bool]] = None,
                 has_disaster_recovery_instances: Optional[pulumi.Input[builtins.bool]] = None,
                 has_green_instance: Optional[pulumi.Input[builtins.bool]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_status: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type: Optional[pulumi.Input[builtins.str]] = None,
                 lower_case_table_names: Optional[pulumi.Input[builtins.str]] = None,
                 maintenance_window: Optional[pulumi.Input['InstanceMaintenanceWindowArgs']] = None,
                 master_instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 master_instance_name: Optional[pulumi.Input[builtins.str]] = None,
                 memory: Optional[pulumi.Input[builtins.int]] = None,
                 node_cpu_used_percentage: Optional[pulumi.Input[builtins.float]] = None,
                 node_memory_used_percentage: Optional[pulumi.Input[builtins.float]] = None,
                 node_number: Optional[pulumi.Input[builtins.str]] = None,
                 node_space_used_percentage: Optional[pulumi.Input[builtins.float]] = None,
                 node_spec: Optional[pulumi.Input[builtins.str]] = None,
                 nodes: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceNodeArgs']]]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 proxy_detail: Optional[pulumi.Input['InstanceProxyDetailArgs']] = None,
                 storage_audit_log_size: Optional[pulumi.Input[builtins.int]] = None,
                 storage_bin_log_size: Optional[pulumi.Input[builtins.int]] = None,
                 storage_data_size: Optional[pulumi.Input[builtins.int]] = None,
                 storage_error_log_size: Optional[pulumi.Input[builtins.int]] = None,
                 storage_log_size: Optional[pulumi.Input[builtins.int]] = None,
                 storage_slow_log_size: Optional[pulumi.Input[builtins.int]] = None,
                 storage_space: Optional[pulumi.Input[builtins.int]] = None,
                 storage_type: Optional[pulumi.Input[builtins.str]] = None,
                 storage_use: Optional[pulumi.Input[builtins.float]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 super_account_name: Optional[pulumi.Input[builtins.str]] = None,
                 super_account_password: Optional[pulumi.Input[builtins.str]] = None,
                 sync_mode: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]] = None,
                 time_zone: Optional[pulumi.Input[builtins.str]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None,
                 vcpu: Optional[pulumi.Input[builtins.int]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering Instance resources.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allow_list_ids: 白名单 ID。如需绑定多个白名单，白名单 ID 用英文逗号（,）分隔。一个实例最多可绑定 100 个白名单。
        :param pulumi.Input[builtins.str] allow_list_version: 白名单版本。
        :param pulumi.Input['InstanceAutoStorageScalingConfigArgs'] auto_storage_scaling_config: 自动扩容配置。
        :param pulumi.Input[builtins.str] auto_upgrade_minor_version: 实例内核小版本的升级策略。取值：Auto：自动升级。Manual：手动升级。
        :param pulumi.Input[builtins.int] backup_audit_log_size: 备份中审计日志使用的空间。
        :param pulumi.Input[builtins.int] backup_bin_log_size: 备份中 Binlog 日志使用的空间。
        :param pulumi.Input[builtins.int] backup_data_size: 备份中数据使用的空间。
        :param pulumi.Input[builtins.int] backup_error_log_size: 备份中错误日志使用的空间。
        :param pulumi.Input[builtins.int] backup_free_quota_size: 免费的备份存储空间，单位为 GB。
        :param pulumi.Input[builtins.int] backup_log_size: 备份中日志使用的空间。
        :param pulumi.Input[builtins.int] backup_slow_log_size: 备份中慢日志使用的空间。
        :param pulumi.Input[builtins.float] backup_use: 实例的备份已使用的空间，单位为 GB。
        :param pulumi.Input[builtins.int] basic_backup_binlog_size: 基础备份中 Binlog 日志使用的空间。
        :param pulumi.Input[builtins.int] basic_backup_data_size: 基础备份中数据使用的空间。
        :param pulumi.Input['InstanceChargeDetailArgs'] charge_detail: 付费方式。
        :param pulumi.Input[builtins.int] cpu_num: 实例数据库代理服务的 CPU 核数。
        :param pulumi.Input[builtins.str] created_time: 实例创建本地时间。
        :param pulumi.Input[builtins.str] current_kernel_version: 实例的内核小版本。
        :param pulumi.Input[builtins.str] db_engine_version: 兼容版本。取值：MySQL*5*7：MySQL 5.7 版本。MySQL*8*0：MySQL 8.0 版本。
        :param pulumi.Input[builtins.str] db_param_group_id: 参数模板 ID。默认值为数据库引擎版本对应的默认参数模板。
        :param pulumi.Input[builtins.str] db_time_zone: 时区。支持 UTC -12:00 ~ +13:00。默认值为 Region 所在的 TimeZone。
        :param pulumi.Input[builtins.str] deletion_protection: 是否启用实例的删除保护功能。取值：Enabled：是。Disabled：否。默认值。
        :param pulumi.Input[builtins.str] dr_dts_task_id: 主实例与灾备实例之间的数据同步链路在 DTS 数据同步任务的 ID。
        :param pulumi.Input[builtins.str] dr_dts_task_name: 主实例与灾备实例之间同步任务的名称。
        :param pulumi.Input[builtins.str] dr_dts_task_status: 主实例与灾备实例之间同步任务的状态。
        :param pulumi.Input[builtins.int] dr_seconds_behind_master: 灾备实例与主实例之间的时延。
        :param pulumi.Input[builtins.bool] global_read_only: 是否开启全局只读。取值：true：是。false：否。默认值为 false。
        :param pulumi.Input[builtins.bool] has_disaster_recovery_instances: 实例是否有灾备实例。取值：true：是。false：否。
        :param pulumi.Input[builtins.bool] has_green_instance: 实例是否处于蓝绿部署中。取值：true：是。false：否。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.str] instance_name: 实例名称。
        :param pulumi.Input[builtins.str] instance_status: 实例状态。
        :param pulumi.Input[builtins.str] instance_type: 实例类型。取值：DoubleNode，双节点类型。MultiNode，多节点类型。
        :param pulumi.Input[builtins.str] lower_case_table_names: 表名是否区分大小写，默认取值为 true。取值：false：表名被存储成固定且表名称大小写敏感。true：表名将被存储成小写且表名称大小写不敏感。
        :param pulumi.Input['InstanceMaintenanceWindowArgs'] maintenance_window: 在创建实例时指定实例的可维护时间段。该字段为可选，不设置时默认为一周内每一天的 UTC18:00Z-21:59Z（即北京时间 02:00-05:59）。
        :param pulumi.Input[builtins.str] master_instance_id: 主实例的 ID。
        :param pulumi.Input[builtins.str] master_instance_name: 主实例的名称。
        :param pulumi.Input[builtins.int] memory: 内存大小。单位：GB。
        :param pulumi.Input[builtins.float] node_cpu_used_percentage: 实例主节点 CPU 使用率近一分钟的平均值。
        :param pulumi.Input[builtins.float] node_memory_used_percentage: 实例主节点内存使用率近一分钟的平均值。
        :param pulumi.Input[builtins.str] node_number: 节点数量。
        :param pulumi.Input[builtins.float] node_space_used_percentage: 实例主节点磁盘使用率近一分钟的平均值。
        :param pulumi.Input[builtins.str] node_spec: 节点规格。
        :param pulumi.Input[builtins.int] port: 默认终端的私网端口。端口号的取值范围为 1000~65534，默认值为 3306。创建新的连接终端或开启新地址时，将使用默认终端的私网端口实时配置为默认端口。
        :param pulumi.Input[builtins.str] project_name: 所属项目。
        :param pulumi.Input['InstanceProxyDetailArgs'] proxy_detail: proxy信息
        :param pulumi.Input[builtins.int] storage_audit_log_size: 实例存储空间中审计日志使用的空间。
        :param pulumi.Input[builtins.int] storage_bin_log_size: 实例存储空间中 Binlog 使用的空间。
        :param pulumi.Input[builtins.int] storage_data_size: 实例存储空间中数据使用的空间。
        :param pulumi.Input[builtins.int] storage_error_log_size: 实例存储空间中错误日志使用的空间。
        :param pulumi.Input[builtins.int] storage_log_size: 实例存储空间中日志使用的空间。
        :param pulumi.Input[builtins.int] storage_slow_log_size: 实例存储空间中慢日志使用的空间。
        :param pulumi.Input[builtins.int] storage_space: 实例总存储空间。单位为 GB。
        :param pulumi.Input[builtins.str] storage_type: 实例的存储类型。取值范围：LocalSSD：本地盘。CloudESSD*FlexPL：FlexPL 云盘。CloudESSD*PL0：PL0 云盘。
        :param pulumi.Input[builtins.float] storage_use: 实例已使用用存储空间，单位为 GB。
        :param pulumi.Input[builtins.str] subnet_id: 子网 ID。
        :param pulumi.Input[builtins.str] super_account_name: 高权限账号名称。不传此参数默认不创建高权限账号。
        :param pulumi.Input[builtins.str] super_account_password: 高权限账号的密码。密码规则如下：长度为 8~32 个字符。由大写字母、小写字母、数字、特殊字符中的至少三种组成。特殊字符为 !@#$%^&*()_+-=,.&?|/。
        :param pulumi.Input[builtins.str] sync_mode: 数据同步方式：SemiSync：半同步。Async：异步。
        :param pulumi.Input[builtins.str] time_zone: 时区。
        :param pulumi.Input[builtins.str] updated_time: 实例更新本地时间。
        :param pulumi.Input[builtins.int] vcpu: CPU 大小。例如：1 表示 1U。
        :param pulumi.Input[builtins.str] vpc_id: 专有网络（VPC） ID。
        :param pulumi.Input[builtins.str] zone_id: 实例主节点所在可用区。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] zone_ids: 实例各节点所在的可用区列表。
        """
        if address_objects is not None:
            pulumi.set(__self__, "address_objects", address_objects)
        if allow_list_ids is not None:
            pulumi.set(__self__, "allow_list_ids", allow_list_ids)
        if allow_list_version is not None:
            pulumi.set(__self__, "allow_list_version", allow_list_version)
        if auto_storage_scaling_config is not None:
            pulumi.set(__self__, "auto_storage_scaling_config", auto_storage_scaling_config)
        if auto_upgrade_minor_version is not None:
            pulumi.set(__self__, "auto_upgrade_minor_version", auto_upgrade_minor_version)
        if backup_audit_log_size is not None:
            pulumi.set(__self__, "backup_audit_log_size", backup_audit_log_size)
        if backup_bin_log_size is not None:
            pulumi.set(__self__, "backup_bin_log_size", backup_bin_log_size)
        if backup_data_size is not None:
            pulumi.set(__self__, "backup_data_size", backup_data_size)
        if backup_error_log_size is not None:
            pulumi.set(__self__, "backup_error_log_size", backup_error_log_size)
        if backup_free_quota_size is not None:
            pulumi.set(__self__, "backup_free_quota_size", backup_free_quota_size)
        if backup_log_size is not None:
            pulumi.set(__self__, "backup_log_size", backup_log_size)
        if backup_slow_log_size is not None:
            pulumi.set(__self__, "backup_slow_log_size", backup_slow_log_size)
        if backup_use is not None:
            pulumi.set(__self__, "backup_use", backup_use)
        if basic_backup_binlog_size is not None:
            pulumi.set(__self__, "basic_backup_binlog_size", basic_backup_binlog_size)
        if basic_backup_data_size is not None:
            pulumi.set(__self__, "basic_backup_data_size", basic_backup_data_size)
        if charge_detail is not None:
            pulumi.set(__self__, "charge_detail", charge_detail)
        if cpu_num is not None:
            pulumi.set(__self__, "cpu_num", cpu_num)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if current_kernel_version is not None:
            pulumi.set(__self__, "current_kernel_version", current_kernel_version)
        if db_engine_version is not None:
            pulumi.set(__self__, "db_engine_version", db_engine_version)
        if db_param_group_id is not None:
            pulumi.set(__self__, "db_param_group_id", db_param_group_id)
        if db_time_zone is not None:
            pulumi.set(__self__, "db_time_zone", db_time_zone)
        if deletion_protection is not None:
            pulumi.set(__self__, "deletion_protection", deletion_protection)
        if disaster_recovery_instances is not None:
            pulumi.set(__self__, "disaster_recovery_instances", disaster_recovery_instances)
        if dr_dts_task_id is not None:
            pulumi.set(__self__, "dr_dts_task_id", dr_dts_task_id)
        if dr_dts_task_name is not None:
            pulumi.set(__self__, "dr_dts_task_name", dr_dts_task_name)
        if dr_dts_task_status is not None:
            pulumi.set(__self__, "dr_dts_task_status", dr_dts_task_status)
        if dr_seconds_behind_master is not None:
            pulumi.set(__self__, "dr_seconds_behind_master", dr_seconds_behind_master)
        if endpoints is not None:
            pulumi.set(__self__, "endpoints", endpoints)
        if global_read_only is not None:
            pulumi.set(__self__, "global_read_only", global_read_only)
        if has_disaster_recovery_instances is not None:
            pulumi.set(__self__, "has_disaster_recovery_instances", has_disaster_recovery_instances)
        if has_green_instance is not None:
            pulumi.set(__self__, "has_green_instance", has_green_instance)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if instance_name is not None:
            pulumi.set(__self__, "instance_name", instance_name)
        if instance_status is not None:
            pulumi.set(__self__, "instance_status", instance_status)
        if instance_type is not None:
            pulumi.set(__self__, "instance_type", instance_type)
        if lower_case_table_names is not None:
            pulumi.set(__self__, "lower_case_table_names", lower_case_table_names)
        if maintenance_window is not None:
            pulumi.set(__self__, "maintenance_window", maintenance_window)
        if master_instance_id is not None:
            pulumi.set(__self__, "master_instance_id", master_instance_id)
        if master_instance_name is not None:
            pulumi.set(__self__, "master_instance_name", master_instance_name)
        if memory is not None:
            pulumi.set(__self__, "memory", memory)
        if node_cpu_used_percentage is not None:
            pulumi.set(__self__, "node_cpu_used_percentage", node_cpu_used_percentage)
        if node_memory_used_percentage is not None:
            pulumi.set(__self__, "node_memory_used_percentage", node_memory_used_percentage)
        if node_number is not None:
            pulumi.set(__self__, "node_number", node_number)
        if node_space_used_percentage is not None:
            pulumi.set(__self__, "node_space_used_percentage", node_space_used_percentage)
        if node_spec is not None:
            pulumi.set(__self__, "node_spec", node_spec)
        if nodes is not None:
            pulumi.set(__self__, "nodes", nodes)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if proxy_detail is not None:
            pulumi.set(__self__, "proxy_detail", proxy_detail)
        if storage_audit_log_size is not None:
            pulumi.set(__self__, "storage_audit_log_size", storage_audit_log_size)
        if storage_bin_log_size is not None:
            pulumi.set(__self__, "storage_bin_log_size", storage_bin_log_size)
        if storage_data_size is not None:
            pulumi.set(__self__, "storage_data_size", storage_data_size)
        if storage_error_log_size is not None:
            pulumi.set(__self__, "storage_error_log_size", storage_error_log_size)
        if storage_log_size is not None:
            pulumi.set(__self__, "storage_log_size", storage_log_size)
        if storage_slow_log_size is not None:
            pulumi.set(__self__, "storage_slow_log_size", storage_slow_log_size)
        if storage_space is not None:
            pulumi.set(__self__, "storage_space", storage_space)
        if storage_type is not None:
            pulumi.set(__self__, "storage_type", storage_type)
        if storage_use is not None:
            pulumi.set(__self__, "storage_use", storage_use)
        if subnet_id is not None:
            pulumi.set(__self__, "subnet_id", subnet_id)
        if super_account_name is not None:
            pulumi.set(__self__, "super_account_name", super_account_name)
        if super_account_password is not None:
            pulumi.set(__self__, "super_account_password", super_account_password)
        if sync_mode is not None:
            pulumi.set(__self__, "sync_mode", sync_mode)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if time_zone is not None:
            pulumi.set(__self__, "time_zone", time_zone)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)
        if vcpu is not None:
            pulumi.set(__self__, "vcpu", vcpu)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)
        if zone_ids is not None:
            pulumi.set(__self__, "zone_ids", zone_ids)

    @property
    @pulumi.getter(name="addressObjects")
    def address_objects(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstanceAddressObjectArgs']]]]:
        return pulumi.get(self, "address_objects")

    @address_objects.setter
    def address_objects(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceAddressObjectArgs']]]]):
        pulumi.set(self, "address_objects", value)

    @property
    @pulumi.getter(name="allowListIds")
    def allow_list_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        白名单 ID。如需绑定多个白名单，白名单 ID 用英文逗号（,）分隔。一个实例最多可绑定 100 个白名单。
        """
        return pulumi.get(self, "allow_list_ids")

    @allow_list_ids.setter
    def allow_list_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "allow_list_ids", value)

    @property
    @pulumi.getter(name="allowListVersion")
    def allow_list_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单版本。
        """
        return pulumi.get(self, "allow_list_version")

    @allow_list_version.setter
    def allow_list_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_version", value)

    @property
    @pulumi.getter(name="autoStorageScalingConfig")
    def auto_storage_scaling_config(self) -> Optional[pulumi.Input['InstanceAutoStorageScalingConfigArgs']]:
        """
        自动扩容配置。
        """
        return pulumi.get(self, "auto_storage_scaling_config")

    @auto_storage_scaling_config.setter
    def auto_storage_scaling_config(self, value: Optional[pulumi.Input['InstanceAutoStorageScalingConfigArgs']]):
        pulumi.set(self, "auto_storage_scaling_config", value)

    @property
    @pulumi.getter(name="autoUpgradeMinorVersion")
    def auto_upgrade_minor_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例内核小版本的升级策略。取值：Auto：自动升级。Manual：手动升级。
        """
        return pulumi.get(self, "auto_upgrade_minor_version")

    @auto_upgrade_minor_version.setter
    def auto_upgrade_minor_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "auto_upgrade_minor_version", value)

    @property
    @pulumi.getter(name="backupAuditLogSize")
    def backup_audit_log_size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        备份中审计日志使用的空间。
        """
        return pulumi.get(self, "backup_audit_log_size")

    @backup_audit_log_size.setter
    def backup_audit_log_size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "backup_audit_log_size", value)

    @property
    @pulumi.getter(name="backupBinLogSize")
    def backup_bin_log_size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        备份中 Binlog 日志使用的空间。
        """
        return pulumi.get(self, "backup_bin_log_size")

    @backup_bin_log_size.setter
    def backup_bin_log_size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "backup_bin_log_size", value)

    @property
    @pulumi.getter(name="backupDataSize")
    def backup_data_size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        备份中数据使用的空间。
        """
        return pulumi.get(self, "backup_data_size")

    @backup_data_size.setter
    def backup_data_size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "backup_data_size", value)

    @property
    @pulumi.getter(name="backupErrorLogSize")
    def backup_error_log_size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        备份中错误日志使用的空间。
        """
        return pulumi.get(self, "backup_error_log_size")

    @backup_error_log_size.setter
    def backup_error_log_size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "backup_error_log_size", value)

    @property
    @pulumi.getter(name="backupFreeQuotaSize")
    def backup_free_quota_size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        免费的备份存储空间，单位为 GB。
        """
        return pulumi.get(self, "backup_free_quota_size")

    @backup_free_quota_size.setter
    def backup_free_quota_size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "backup_free_quota_size", value)

    @property
    @pulumi.getter(name="backupLogSize")
    def backup_log_size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        备份中日志使用的空间。
        """
        return pulumi.get(self, "backup_log_size")

    @backup_log_size.setter
    def backup_log_size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "backup_log_size", value)

    @property
    @pulumi.getter(name="backupSlowLogSize")
    def backup_slow_log_size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        备份中慢日志使用的空间。
        """
        return pulumi.get(self, "backup_slow_log_size")

    @backup_slow_log_size.setter
    def backup_slow_log_size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "backup_slow_log_size", value)

    @property
    @pulumi.getter(name="backupUse")
    def backup_use(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        实例的备份已使用的空间，单位为 GB。
        """
        return pulumi.get(self, "backup_use")

    @backup_use.setter
    def backup_use(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "backup_use", value)

    @property
    @pulumi.getter(name="basicBackupBinlogSize")
    def basic_backup_binlog_size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        基础备份中 Binlog 日志使用的空间。
        """
        return pulumi.get(self, "basic_backup_binlog_size")

    @basic_backup_binlog_size.setter
    def basic_backup_binlog_size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "basic_backup_binlog_size", value)

    @property
    @pulumi.getter(name="basicBackupDataSize")
    def basic_backup_data_size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        基础备份中数据使用的空间。
        """
        return pulumi.get(self, "basic_backup_data_size")

    @basic_backup_data_size.setter
    def basic_backup_data_size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "basic_backup_data_size", value)

    @property
    @pulumi.getter(name="chargeDetail")
    def charge_detail(self) -> Optional[pulumi.Input['InstanceChargeDetailArgs']]:
        """
        付费方式。
        """
        return pulumi.get(self, "charge_detail")

    @charge_detail.setter
    def charge_detail(self, value: Optional[pulumi.Input['InstanceChargeDetailArgs']]):
        pulumi.set(self, "charge_detail", value)

    @property
    @pulumi.getter(name="cpuNum")
    def cpu_num(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        实例数据库代理服务的 CPU 核数。
        """
        return pulumi.get(self, "cpu_num")

    @cpu_num.setter
    def cpu_num(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "cpu_num", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例创建本地时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="currentKernelVersion")
    def current_kernel_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的内核小版本。
        """
        return pulumi.get(self, "current_kernel_version")

    @current_kernel_version.setter
    def current_kernel_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "current_kernel_version", value)

    @property
    @pulumi.getter(name="dbEngineVersion")
    def db_engine_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        兼容版本。取值：MySQL*5*7：MySQL 5.7 版本。MySQL*8*0：MySQL 8.0 版本。
        """
        return pulumi.get(self, "db_engine_version")

    @db_engine_version.setter
    def db_engine_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "db_engine_version", value)

    @property
    @pulumi.getter(name="dbParamGroupId")
    def db_param_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        参数模板 ID。默认值为数据库引擎版本对应的默认参数模板。
        """
        return pulumi.get(self, "db_param_group_id")

    @db_param_group_id.setter
    def db_param_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "db_param_group_id", value)

    @property
    @pulumi.getter(name="dbTimeZone")
    def db_time_zone(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        时区。支持 UTC -12:00 ~ +13:00。默认值为 Region 所在的 TimeZone。
        """
        return pulumi.get(self, "db_time_zone")

    @db_time_zone.setter
    def db_time_zone(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "db_time_zone", value)

    @property
    @pulumi.getter(name="deletionProtection")
    def deletion_protection(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        是否启用实例的删除保护功能。取值：Enabled：是。Disabled：否。默认值。
        """
        return pulumi.get(self, "deletion_protection")

    @deletion_protection.setter
    def deletion_protection(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "deletion_protection", value)

    @property
    @pulumi.getter(name="disasterRecoveryInstances")
    def disaster_recovery_instances(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstanceDisasterRecoveryInstanceArgs']]]]:
        return pulumi.get(self, "disaster_recovery_instances")

    @disaster_recovery_instances.setter
    def disaster_recovery_instances(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceDisasterRecoveryInstanceArgs']]]]):
        pulumi.set(self, "disaster_recovery_instances", value)

    @property
    @pulumi.getter(name="drDtsTaskId")
    def dr_dts_task_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        主实例与灾备实例之间的数据同步链路在 DTS 数据同步任务的 ID。
        """
        return pulumi.get(self, "dr_dts_task_id")

    @dr_dts_task_id.setter
    def dr_dts_task_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "dr_dts_task_id", value)

    @property
    @pulumi.getter(name="drDtsTaskName")
    def dr_dts_task_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        主实例与灾备实例之间同步任务的名称。
        """
        return pulumi.get(self, "dr_dts_task_name")

    @dr_dts_task_name.setter
    def dr_dts_task_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "dr_dts_task_name", value)

    @property
    @pulumi.getter(name="drDtsTaskStatus")
    def dr_dts_task_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        主实例与灾备实例之间同步任务的状态。
        """
        return pulumi.get(self, "dr_dts_task_status")

    @dr_dts_task_status.setter
    def dr_dts_task_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "dr_dts_task_status", value)

    @property
    @pulumi.getter(name="drSecondsBehindMaster")
    def dr_seconds_behind_master(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        灾备实例与主实例之间的时延。
        """
        return pulumi.get(self, "dr_seconds_behind_master")

    @dr_seconds_behind_master.setter
    def dr_seconds_behind_master(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "dr_seconds_behind_master", value)

    @property
    @pulumi.getter
    def endpoints(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstanceEndpointArgs']]]]:
        return pulumi.get(self, "endpoints")

    @endpoints.setter
    def endpoints(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceEndpointArgs']]]]):
        pulumi.set(self, "endpoints", value)

    @property
    @pulumi.getter(name="globalReadOnly")
    def global_read_only(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启全局只读。取值：true：是。false：否。默认值为 false。
        """
        return pulumi.get(self, "global_read_only")

    @global_read_only.setter
    def global_read_only(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "global_read_only", value)

    @property
    @pulumi.getter(name="hasDisasterRecoveryInstances")
    def has_disaster_recovery_instances(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        实例是否有灾备实例。取值：true：是。false：否。
        """
        return pulumi.get(self, "has_disaster_recovery_instances")

    @has_disaster_recovery_instances.setter
    def has_disaster_recovery_instances(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "has_disaster_recovery_instances", value)

    @property
    @pulumi.getter(name="hasGreenInstance")
    def has_green_instance(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        实例是否处于蓝绿部署中。取值：true：是。false：否。
        """
        return pulumi.get(self, "has_green_instance")

    @has_green_instance.setter
    def has_green_instance(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "has_green_instance", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例名称。
        """
        return pulumi.get(self, "instance_name")

    @instance_name.setter
    def instance_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_name", value)

    @property
    @pulumi.getter(name="instanceStatus")
    def instance_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例状态。
        """
        return pulumi.get(self, "instance_status")

    @instance_status.setter
    def instance_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_status", value)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例类型。取值：DoubleNode，双节点类型。MultiNode，多节点类型。
        """
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_type", value)

    @property
    @pulumi.getter(name="lowerCaseTableNames")
    def lower_case_table_names(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        表名是否区分大小写，默认取值为 true。取值：false：表名被存储成固定且表名称大小写敏感。true：表名将被存储成小写且表名称大小写不敏感。
        """
        return pulumi.get(self, "lower_case_table_names")

    @lower_case_table_names.setter
    def lower_case_table_names(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "lower_case_table_names", value)

    @property
    @pulumi.getter(name="maintenanceWindow")
    def maintenance_window(self) -> Optional[pulumi.Input['InstanceMaintenanceWindowArgs']]:
        """
        在创建实例时指定实例的可维护时间段。该字段为可选，不设置时默认为一周内每一天的 UTC18:00Z-21:59Z（即北京时间 02:00-05:59）。
        """
        return pulumi.get(self, "maintenance_window")

    @maintenance_window.setter
    def maintenance_window(self, value: Optional[pulumi.Input['InstanceMaintenanceWindowArgs']]):
        pulumi.set(self, "maintenance_window", value)

    @property
    @pulumi.getter(name="masterInstanceId")
    def master_instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        主实例的 ID。
        """
        return pulumi.get(self, "master_instance_id")

    @master_instance_id.setter
    def master_instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "master_instance_id", value)

    @property
    @pulumi.getter(name="masterInstanceName")
    def master_instance_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        主实例的名称。
        """
        return pulumi.get(self, "master_instance_name")

    @master_instance_name.setter
    def master_instance_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "master_instance_name", value)

    @property
    @pulumi.getter
    def memory(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        内存大小。单位：GB。
        """
        return pulumi.get(self, "memory")

    @memory.setter
    def memory(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "memory", value)

    @property
    @pulumi.getter(name="nodeCpuUsedPercentage")
    def node_cpu_used_percentage(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        实例主节点 CPU 使用率近一分钟的平均值。
        """
        return pulumi.get(self, "node_cpu_used_percentage")

    @node_cpu_used_percentage.setter
    def node_cpu_used_percentage(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "node_cpu_used_percentage", value)

    @property
    @pulumi.getter(name="nodeMemoryUsedPercentage")
    def node_memory_used_percentage(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        实例主节点内存使用率近一分钟的平均值。
        """
        return pulumi.get(self, "node_memory_used_percentage")

    @node_memory_used_percentage.setter
    def node_memory_used_percentage(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "node_memory_used_percentage", value)

    @property
    @pulumi.getter(name="nodeNumber")
    def node_number(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        节点数量。
        """
        return pulumi.get(self, "node_number")

    @node_number.setter
    def node_number(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "node_number", value)

    @property
    @pulumi.getter(name="nodeSpaceUsedPercentage")
    def node_space_used_percentage(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        实例主节点磁盘使用率近一分钟的平均值。
        """
        return pulumi.get(self, "node_space_used_percentage")

    @node_space_used_percentage.setter
    def node_space_used_percentage(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "node_space_used_percentage", value)

    @property
    @pulumi.getter(name="nodeSpec")
    def node_spec(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        节点规格。
        """
        return pulumi.get(self, "node_spec")

    @node_spec.setter
    def node_spec(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "node_spec", value)

    @property
    @pulumi.getter
    def nodes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstanceNodeArgs']]]]:
        return pulumi.get(self, "nodes")

    @nodes.setter
    def nodes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceNodeArgs']]]]):
        pulumi.set(self, "nodes", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        默认终端的私网端口。端口号的取值范围为 1000~65534，默认值为 3306。创建新的连接终端或开启新地址时，将使用默认终端的私网端口实时配置为默认端口。
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        所属项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="proxyDetail")
    def proxy_detail(self) -> Optional[pulumi.Input['InstanceProxyDetailArgs']]:
        """
        proxy信息
        """
        return pulumi.get(self, "proxy_detail")

    @proxy_detail.setter
    def proxy_detail(self, value: Optional[pulumi.Input['InstanceProxyDetailArgs']]):
        pulumi.set(self, "proxy_detail", value)

    @property
    @pulumi.getter(name="storageAuditLogSize")
    def storage_audit_log_size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        实例存储空间中审计日志使用的空间。
        """
        return pulumi.get(self, "storage_audit_log_size")

    @storage_audit_log_size.setter
    def storage_audit_log_size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "storage_audit_log_size", value)

    @property
    @pulumi.getter(name="storageBinLogSize")
    def storage_bin_log_size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        实例存储空间中 Binlog 使用的空间。
        """
        return pulumi.get(self, "storage_bin_log_size")

    @storage_bin_log_size.setter
    def storage_bin_log_size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "storage_bin_log_size", value)

    @property
    @pulumi.getter(name="storageDataSize")
    def storage_data_size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        实例存储空间中数据使用的空间。
        """
        return pulumi.get(self, "storage_data_size")

    @storage_data_size.setter
    def storage_data_size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "storage_data_size", value)

    @property
    @pulumi.getter(name="storageErrorLogSize")
    def storage_error_log_size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        实例存储空间中错误日志使用的空间。
        """
        return pulumi.get(self, "storage_error_log_size")

    @storage_error_log_size.setter
    def storage_error_log_size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "storage_error_log_size", value)

    @property
    @pulumi.getter(name="storageLogSize")
    def storage_log_size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        实例存储空间中日志使用的空间。
        """
        return pulumi.get(self, "storage_log_size")

    @storage_log_size.setter
    def storage_log_size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "storage_log_size", value)

    @property
    @pulumi.getter(name="storageSlowLogSize")
    def storage_slow_log_size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        实例存储空间中慢日志使用的空间。
        """
        return pulumi.get(self, "storage_slow_log_size")

    @storage_slow_log_size.setter
    def storage_slow_log_size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "storage_slow_log_size", value)

    @property
    @pulumi.getter(name="storageSpace")
    def storage_space(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        实例总存储空间。单位为 GB。
        """
        return pulumi.get(self, "storage_space")

    @storage_space.setter
    def storage_space(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "storage_space", value)

    @property
    @pulumi.getter(name="storageType")
    def storage_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的存储类型。取值范围：LocalSSD：本地盘。CloudESSD*FlexPL：FlexPL 云盘。CloudESSD*PL0：PL0 云盘。
        """
        return pulumi.get(self, "storage_type")

    @storage_type.setter
    def storage_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "storage_type", value)

    @property
    @pulumi.getter(name="storageUse")
    def storage_use(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        实例已使用用存储空间，单位为 GB。
        """
        return pulumi.get(self, "storage_use")

    @storage_use.setter
    def storage_use(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "storage_use", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子网 ID。
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "subnet_id", value)

    @property
    @pulumi.getter(name="superAccountName")
    def super_account_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        高权限账号名称。不传此参数默认不创建高权限账号。
        """
        return pulumi.get(self, "super_account_name")

    @super_account_name.setter
    def super_account_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "super_account_name", value)

    @property
    @pulumi.getter(name="superAccountPassword")
    def super_account_password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        高权限账号的密码。密码规则如下：长度为 8~32 个字符。由大写字母、小写字母、数字、特殊字符中的至少三种组成。特殊字符为 !@#$%^&*()_+-=,.&?|/。
        """
        return pulumi.get(self, "super_account_password")

    @super_account_password.setter
    def super_account_password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "super_account_password", value)

    @property
    @pulumi.getter(name="syncMode")
    def sync_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        数据同步方式：SemiSync：半同步。Async：异步。
        """
        return pulumi.get(self, "sync_mode")

    @sync_mode.setter
    def sync_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "sync_mode", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="timeZone")
    def time_zone(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        时区。
        """
        return pulumi.get(self, "time_zone")

    @time_zone.setter
    def time_zone(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "time_zone", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例更新本地时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)

    @property
    @pulumi.getter
    def vcpu(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        CPU 大小。例如：1 表示 1U。
        """
        return pulumi.get(self, "vcpu")

    @vcpu.setter
    def vcpu(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "vcpu", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        专有网络（VPC） ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例主节点所在可用区。
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone_id", value)

    @property
    @pulumi.getter(name="zoneIds")
    def zone_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        实例各节点所在的可用区列表。
        """
        return pulumi.get(self, "zone_ids")

    @zone_ids.setter
    def zone_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "zone_ids", value)


@pulumi.type_token("bytepluscc:rdsmysql/instance:Instance")
class Instance(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_list_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 auto_storage_scaling_config: Optional[pulumi.Input[Union['InstanceAutoStorageScalingConfigArgs', 'InstanceAutoStorageScalingConfigArgsDict']]] = None,
                 auto_upgrade_minor_version: Optional[pulumi.Input[builtins.str]] = None,
                 charge_detail: Optional[pulumi.Input[Union['InstanceChargeDetailArgs', 'InstanceChargeDetailArgsDict']]] = None,
                 cpu_num: Optional[pulumi.Input[builtins.int]] = None,
                 db_engine_version: Optional[pulumi.Input[builtins.str]] = None,
                 db_param_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 db_time_zone: Optional[pulumi.Input[builtins.str]] = None,
                 deletion_protection: Optional[pulumi.Input[builtins.str]] = None,
                 global_read_only: Optional[pulumi.Input[builtins.bool]] = None,
                 instance_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type: Optional[pulumi.Input[builtins.str]] = None,
                 lower_case_table_names: Optional[pulumi.Input[builtins.str]] = None,
                 maintenance_window: Optional[pulumi.Input[Union['InstanceMaintenanceWindowArgs', 'InstanceMaintenanceWindowArgsDict']]] = None,
                 node_spec: Optional[pulumi.Input[builtins.str]] = None,
                 nodes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceNodeArgs', 'InstanceNodeArgsDict']]]]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 storage_space: Optional[pulumi.Input[builtins.int]] = None,
                 storage_type: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 super_account_name: Optional[pulumi.Input[builtins.str]] = None,
                 super_account_password: Optional[pulumi.Input[builtins.str]] = None,
                 sync_mode: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceTagArgs', 'InstanceTagArgsDict']]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        云数据库 MySQL 版是火山引擎基于开源数据库 MySQL 打造的弹性、可靠的在线关系型数据库服务。 MySQL 实例使用云原生方式部署，结合本地 SSD 存储类型，提供高性能读写能力；完全兼容 MySQL 引擎，并提供实例管理、备份恢复、日志管理、监控告警、数据迁移等全套解决方案，帮助企业简化繁杂的数据库管理和运维任务，使企业有更多的时间与资源聚焦于自己的核心业务。

        ## Import

        ```sh
        $ pulumi import bytepluscc:rdsmysql/instance:Instance example "instance_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allow_list_ids: 白名单 ID。如需绑定多个白名单，白名单 ID 用英文逗号（,）分隔。一个实例最多可绑定 100 个白名单。
        :param pulumi.Input[Union['InstanceAutoStorageScalingConfigArgs', 'InstanceAutoStorageScalingConfigArgsDict']] auto_storage_scaling_config: 自动扩容配置。
        :param pulumi.Input[builtins.str] auto_upgrade_minor_version: 实例内核小版本的升级策略。取值：Auto：自动升级。Manual：手动升级。
        :param pulumi.Input[Union['InstanceChargeDetailArgs', 'InstanceChargeDetailArgsDict']] charge_detail: 付费方式。
        :param pulumi.Input[builtins.int] cpu_num: 实例数据库代理服务的 CPU 核数。
        :param pulumi.Input[builtins.str] db_engine_version: 兼容版本。取值：MySQL*5*7：MySQL 5.7 版本。MySQL*8*0：MySQL 8.0 版本。
        :param pulumi.Input[builtins.str] db_param_group_id: 参数模板 ID。默认值为数据库引擎版本对应的默认参数模板。
        :param pulumi.Input[builtins.str] db_time_zone: 时区。支持 UTC -12:00 ~ +13:00。默认值为 Region 所在的 TimeZone。
        :param pulumi.Input[builtins.str] deletion_protection: 是否启用实例的删除保护功能。取值：Enabled：是。Disabled：否。默认值。
        :param pulumi.Input[builtins.bool] global_read_only: 是否开启全局只读。取值：true：是。false：否。默认值为 false。
        :param pulumi.Input[builtins.str] instance_name: 实例名称。
        :param pulumi.Input[builtins.str] instance_type: 实例类型。取值：DoubleNode，双节点类型。MultiNode，多节点类型。
        :param pulumi.Input[builtins.str] lower_case_table_names: 表名是否区分大小写，默认取值为 true。取值：false：表名被存储成固定且表名称大小写敏感。true：表名将被存储成小写且表名称大小写不敏感。
        :param pulumi.Input[Union['InstanceMaintenanceWindowArgs', 'InstanceMaintenanceWindowArgsDict']] maintenance_window: 在创建实例时指定实例的可维护时间段。该字段为可选，不设置时默认为一周内每一天的 UTC18:00Z-21:59Z（即北京时间 02:00-05:59）。
        :param pulumi.Input[builtins.str] node_spec: 节点规格。
        :param pulumi.Input[builtins.int] port: 默认终端的私网端口。端口号的取值范围为 1000~65534，默认值为 3306。创建新的连接终端或开启新地址时，将使用默认终端的私网端口实时配置为默认端口。
        :param pulumi.Input[builtins.str] project_name: 所属项目。
        :param pulumi.Input[builtins.int] storage_space: 实例总存储空间。单位为 GB。
        :param pulumi.Input[builtins.str] storage_type: 实例的存储类型。取值范围：LocalSSD：本地盘。CloudESSD*FlexPL：FlexPL 云盘。CloudESSD*PL0：PL0 云盘。
        :param pulumi.Input[builtins.str] subnet_id: 子网 ID。
        :param pulumi.Input[builtins.str] super_account_name: 高权限账号名称。不传此参数默认不创建高权限账号。
        :param pulumi.Input[builtins.str] super_account_password: 高权限账号的密码。密码规则如下：长度为 8~32 个字符。由大写字母、小写字母、数字、特殊字符中的至少三种组成。特殊字符为 !@#$%^&*()_+-=,.&?|/。
        :param pulumi.Input[builtins.str] sync_mode: 数据同步方式：SemiSync：半同步。Async：异步。
        :param pulumi.Input[builtins.str] vpc_id: 专有网络（VPC） ID。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InstanceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        云数据库 MySQL 版是火山引擎基于开源数据库 MySQL 打造的弹性、可靠的在线关系型数据库服务。 MySQL 实例使用云原生方式部署，结合本地 SSD 存储类型，提供高性能读写能力；完全兼容 MySQL 引擎，并提供实例管理、备份恢复、日志管理、监控告警、数据迁移等全套解决方案，帮助企业简化繁杂的数据库管理和运维任务，使企业有更多的时间与资源聚焦于自己的核心业务。

        ## Import

        ```sh
        $ pulumi import bytepluscc:rdsmysql/instance:Instance example "instance_id"
        ```

        :param str resource_name: The name of the resource.
        :param InstanceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InstanceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_list_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 auto_storage_scaling_config: Optional[pulumi.Input[Union['InstanceAutoStorageScalingConfigArgs', 'InstanceAutoStorageScalingConfigArgsDict']]] = None,
                 auto_upgrade_minor_version: Optional[pulumi.Input[builtins.str]] = None,
                 charge_detail: Optional[pulumi.Input[Union['InstanceChargeDetailArgs', 'InstanceChargeDetailArgsDict']]] = None,
                 cpu_num: Optional[pulumi.Input[builtins.int]] = None,
                 db_engine_version: Optional[pulumi.Input[builtins.str]] = None,
                 db_param_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 db_time_zone: Optional[pulumi.Input[builtins.str]] = None,
                 deletion_protection: Optional[pulumi.Input[builtins.str]] = None,
                 global_read_only: Optional[pulumi.Input[builtins.bool]] = None,
                 instance_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type: Optional[pulumi.Input[builtins.str]] = None,
                 lower_case_table_names: Optional[pulumi.Input[builtins.str]] = None,
                 maintenance_window: Optional[pulumi.Input[Union['InstanceMaintenanceWindowArgs', 'InstanceMaintenanceWindowArgsDict']]] = None,
                 node_spec: Optional[pulumi.Input[builtins.str]] = None,
                 nodes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceNodeArgs', 'InstanceNodeArgsDict']]]]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 storage_space: Optional[pulumi.Input[builtins.int]] = None,
                 storage_type: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 super_account_name: Optional[pulumi.Input[builtins.str]] = None,
                 super_account_password: Optional[pulumi.Input[builtins.str]] = None,
                 sync_mode: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceTagArgs', 'InstanceTagArgsDict']]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InstanceArgs.__new__(InstanceArgs)

            __props__.__dict__["allow_list_ids"] = allow_list_ids
            __props__.__dict__["auto_storage_scaling_config"] = auto_storage_scaling_config
            __props__.__dict__["auto_upgrade_minor_version"] = auto_upgrade_minor_version
            if charge_detail is None and not opts.urn:
                raise TypeError("Missing required property 'charge_detail'")
            __props__.__dict__["charge_detail"] = charge_detail
            __props__.__dict__["cpu_num"] = cpu_num
            if db_engine_version is None and not opts.urn:
                raise TypeError("Missing required property 'db_engine_version'")
            __props__.__dict__["db_engine_version"] = db_engine_version
            __props__.__dict__["db_param_group_id"] = db_param_group_id
            __props__.__dict__["db_time_zone"] = db_time_zone
            __props__.__dict__["deletion_protection"] = deletion_protection
            __props__.__dict__["global_read_only"] = global_read_only
            __props__.__dict__["instance_name"] = instance_name
            __props__.__dict__["instance_type"] = instance_type
            __props__.__dict__["lower_case_table_names"] = lower_case_table_names
            __props__.__dict__["maintenance_window"] = maintenance_window
            __props__.__dict__["node_spec"] = node_spec
            if nodes is None and not opts.urn:
                raise TypeError("Missing required property 'nodes'")
            __props__.__dict__["nodes"] = nodes
            __props__.__dict__["port"] = port
            __props__.__dict__["project_name"] = project_name
            if storage_space is None and not opts.urn:
                raise TypeError("Missing required property 'storage_space'")
            __props__.__dict__["storage_space"] = storage_space
            if storage_type is None and not opts.urn:
                raise TypeError("Missing required property 'storage_type'")
            __props__.__dict__["storage_type"] = storage_type
            if subnet_id is None and not opts.urn:
                raise TypeError("Missing required property 'subnet_id'")
            __props__.__dict__["subnet_id"] = subnet_id
            __props__.__dict__["super_account_name"] = super_account_name
            __props__.__dict__["super_account_password"] = super_account_password
            __props__.__dict__["sync_mode"] = sync_mode
            __props__.__dict__["tags"] = tags
            if vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_id'")
            __props__.__dict__["vpc_id"] = vpc_id
            __props__.__dict__["address_objects"] = None
            __props__.__dict__["allow_list_version"] = None
            __props__.__dict__["backup_audit_log_size"] = None
            __props__.__dict__["backup_bin_log_size"] = None
            __props__.__dict__["backup_data_size"] = None
            __props__.__dict__["backup_error_log_size"] = None
            __props__.__dict__["backup_free_quota_size"] = None
            __props__.__dict__["backup_log_size"] = None
            __props__.__dict__["backup_slow_log_size"] = None
            __props__.__dict__["backup_use"] = None
            __props__.__dict__["basic_backup_binlog_size"] = None
            __props__.__dict__["basic_backup_data_size"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["current_kernel_version"] = None
            __props__.__dict__["disaster_recovery_instances"] = None
            __props__.__dict__["dr_dts_task_id"] = None
            __props__.__dict__["dr_dts_task_name"] = None
            __props__.__dict__["dr_dts_task_status"] = None
            __props__.__dict__["dr_seconds_behind_master"] = None
            __props__.__dict__["endpoints"] = None
            __props__.__dict__["has_disaster_recovery_instances"] = None
            __props__.__dict__["has_green_instance"] = None
            __props__.__dict__["instance_id"] = None
            __props__.__dict__["instance_status"] = None
            __props__.__dict__["master_instance_id"] = None
            __props__.__dict__["master_instance_name"] = None
            __props__.__dict__["memory"] = None
            __props__.__dict__["node_cpu_used_percentage"] = None
            __props__.__dict__["node_memory_used_percentage"] = None
            __props__.__dict__["node_number"] = None
            __props__.__dict__["node_space_used_percentage"] = None
            __props__.__dict__["proxy_detail"] = None
            __props__.__dict__["storage_audit_log_size"] = None
            __props__.__dict__["storage_bin_log_size"] = None
            __props__.__dict__["storage_data_size"] = None
            __props__.__dict__["storage_error_log_size"] = None
            __props__.__dict__["storage_log_size"] = None
            __props__.__dict__["storage_slow_log_size"] = None
            __props__.__dict__["storage_use"] = None
            __props__.__dict__["time_zone"] = None
            __props__.__dict__["updated_time"] = None
            __props__.__dict__["vcpu"] = None
            __props__.__dict__["zone_id"] = None
            __props__.__dict__["zone_ids"] = None
        super(Instance, __self__).__init__(
            'bytepluscc:rdsmysql/instance:Instance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            address_objects: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceAddressObjectArgs', 'InstanceAddressObjectArgsDict']]]]] = None,
            allow_list_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            allow_list_version: Optional[pulumi.Input[builtins.str]] = None,
            auto_storage_scaling_config: Optional[pulumi.Input[Union['InstanceAutoStorageScalingConfigArgs', 'InstanceAutoStorageScalingConfigArgsDict']]] = None,
            auto_upgrade_minor_version: Optional[pulumi.Input[builtins.str]] = None,
            backup_audit_log_size: Optional[pulumi.Input[builtins.int]] = None,
            backup_bin_log_size: Optional[pulumi.Input[builtins.int]] = None,
            backup_data_size: Optional[pulumi.Input[builtins.int]] = None,
            backup_error_log_size: Optional[pulumi.Input[builtins.int]] = None,
            backup_free_quota_size: Optional[pulumi.Input[builtins.int]] = None,
            backup_log_size: Optional[pulumi.Input[builtins.int]] = None,
            backup_slow_log_size: Optional[pulumi.Input[builtins.int]] = None,
            backup_use: Optional[pulumi.Input[builtins.float]] = None,
            basic_backup_binlog_size: Optional[pulumi.Input[builtins.int]] = None,
            basic_backup_data_size: Optional[pulumi.Input[builtins.int]] = None,
            charge_detail: Optional[pulumi.Input[Union['InstanceChargeDetailArgs', 'InstanceChargeDetailArgsDict']]] = None,
            cpu_num: Optional[pulumi.Input[builtins.int]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            current_kernel_version: Optional[pulumi.Input[builtins.str]] = None,
            db_engine_version: Optional[pulumi.Input[builtins.str]] = None,
            db_param_group_id: Optional[pulumi.Input[builtins.str]] = None,
            db_time_zone: Optional[pulumi.Input[builtins.str]] = None,
            deletion_protection: Optional[pulumi.Input[builtins.str]] = None,
            disaster_recovery_instances: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceDisasterRecoveryInstanceArgs', 'InstanceDisasterRecoveryInstanceArgsDict']]]]] = None,
            dr_dts_task_id: Optional[pulumi.Input[builtins.str]] = None,
            dr_dts_task_name: Optional[pulumi.Input[builtins.str]] = None,
            dr_dts_task_status: Optional[pulumi.Input[builtins.str]] = None,
            dr_seconds_behind_master: Optional[pulumi.Input[builtins.int]] = None,
            endpoints: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceEndpointArgs', 'InstanceEndpointArgsDict']]]]] = None,
            global_read_only: Optional[pulumi.Input[builtins.bool]] = None,
            has_disaster_recovery_instances: Optional[pulumi.Input[builtins.bool]] = None,
            has_green_instance: Optional[pulumi.Input[builtins.bool]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            instance_name: Optional[pulumi.Input[builtins.str]] = None,
            instance_status: Optional[pulumi.Input[builtins.str]] = None,
            instance_type: Optional[pulumi.Input[builtins.str]] = None,
            lower_case_table_names: Optional[pulumi.Input[builtins.str]] = None,
            maintenance_window: Optional[pulumi.Input[Union['InstanceMaintenanceWindowArgs', 'InstanceMaintenanceWindowArgsDict']]] = None,
            master_instance_id: Optional[pulumi.Input[builtins.str]] = None,
            master_instance_name: Optional[pulumi.Input[builtins.str]] = None,
            memory: Optional[pulumi.Input[builtins.int]] = None,
            node_cpu_used_percentage: Optional[pulumi.Input[builtins.float]] = None,
            node_memory_used_percentage: Optional[pulumi.Input[builtins.float]] = None,
            node_number: Optional[pulumi.Input[builtins.str]] = None,
            node_space_used_percentage: Optional[pulumi.Input[builtins.float]] = None,
            node_spec: Optional[pulumi.Input[builtins.str]] = None,
            nodes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceNodeArgs', 'InstanceNodeArgsDict']]]]] = None,
            port: Optional[pulumi.Input[builtins.int]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            proxy_detail: Optional[pulumi.Input[Union['InstanceProxyDetailArgs', 'InstanceProxyDetailArgsDict']]] = None,
            storage_audit_log_size: Optional[pulumi.Input[builtins.int]] = None,
            storage_bin_log_size: Optional[pulumi.Input[builtins.int]] = None,
            storage_data_size: Optional[pulumi.Input[builtins.int]] = None,
            storage_error_log_size: Optional[pulumi.Input[builtins.int]] = None,
            storage_log_size: Optional[pulumi.Input[builtins.int]] = None,
            storage_slow_log_size: Optional[pulumi.Input[builtins.int]] = None,
            storage_space: Optional[pulumi.Input[builtins.int]] = None,
            storage_type: Optional[pulumi.Input[builtins.str]] = None,
            storage_use: Optional[pulumi.Input[builtins.float]] = None,
            subnet_id: Optional[pulumi.Input[builtins.str]] = None,
            super_account_name: Optional[pulumi.Input[builtins.str]] = None,
            super_account_password: Optional[pulumi.Input[builtins.str]] = None,
            sync_mode: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceTagArgs', 'InstanceTagArgsDict']]]]] = None,
            time_zone: Optional[pulumi.Input[builtins.str]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None,
            vcpu: Optional[pulumi.Input[builtins.int]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None,
            zone_id: Optional[pulumi.Input[builtins.str]] = None,
            zone_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None) -> 'Instance':
        """
        Get an existing Instance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allow_list_ids: 白名单 ID。如需绑定多个白名单，白名单 ID 用英文逗号（,）分隔。一个实例最多可绑定 100 个白名单。
        :param pulumi.Input[builtins.str] allow_list_version: 白名单版本。
        :param pulumi.Input[Union['InstanceAutoStorageScalingConfigArgs', 'InstanceAutoStorageScalingConfigArgsDict']] auto_storage_scaling_config: 自动扩容配置。
        :param pulumi.Input[builtins.str] auto_upgrade_minor_version: 实例内核小版本的升级策略。取值：Auto：自动升级。Manual：手动升级。
        :param pulumi.Input[builtins.int] backup_audit_log_size: 备份中审计日志使用的空间。
        :param pulumi.Input[builtins.int] backup_bin_log_size: 备份中 Binlog 日志使用的空间。
        :param pulumi.Input[builtins.int] backup_data_size: 备份中数据使用的空间。
        :param pulumi.Input[builtins.int] backup_error_log_size: 备份中错误日志使用的空间。
        :param pulumi.Input[builtins.int] backup_free_quota_size: 免费的备份存储空间，单位为 GB。
        :param pulumi.Input[builtins.int] backup_log_size: 备份中日志使用的空间。
        :param pulumi.Input[builtins.int] backup_slow_log_size: 备份中慢日志使用的空间。
        :param pulumi.Input[builtins.float] backup_use: 实例的备份已使用的空间，单位为 GB。
        :param pulumi.Input[builtins.int] basic_backup_binlog_size: 基础备份中 Binlog 日志使用的空间。
        :param pulumi.Input[builtins.int] basic_backup_data_size: 基础备份中数据使用的空间。
        :param pulumi.Input[Union['InstanceChargeDetailArgs', 'InstanceChargeDetailArgsDict']] charge_detail: 付费方式。
        :param pulumi.Input[builtins.int] cpu_num: 实例数据库代理服务的 CPU 核数。
        :param pulumi.Input[builtins.str] created_time: 实例创建本地时间。
        :param pulumi.Input[builtins.str] current_kernel_version: 实例的内核小版本。
        :param pulumi.Input[builtins.str] db_engine_version: 兼容版本。取值：MySQL*5*7：MySQL 5.7 版本。MySQL*8*0：MySQL 8.0 版本。
        :param pulumi.Input[builtins.str] db_param_group_id: 参数模板 ID。默认值为数据库引擎版本对应的默认参数模板。
        :param pulumi.Input[builtins.str] db_time_zone: 时区。支持 UTC -12:00 ~ +13:00。默认值为 Region 所在的 TimeZone。
        :param pulumi.Input[builtins.str] deletion_protection: 是否启用实例的删除保护功能。取值：Enabled：是。Disabled：否。默认值。
        :param pulumi.Input[builtins.str] dr_dts_task_id: 主实例与灾备实例之间的数据同步链路在 DTS 数据同步任务的 ID。
        :param pulumi.Input[builtins.str] dr_dts_task_name: 主实例与灾备实例之间同步任务的名称。
        :param pulumi.Input[builtins.str] dr_dts_task_status: 主实例与灾备实例之间同步任务的状态。
        :param pulumi.Input[builtins.int] dr_seconds_behind_master: 灾备实例与主实例之间的时延。
        :param pulumi.Input[builtins.bool] global_read_only: 是否开启全局只读。取值：true：是。false：否。默认值为 false。
        :param pulumi.Input[builtins.bool] has_disaster_recovery_instances: 实例是否有灾备实例。取值：true：是。false：否。
        :param pulumi.Input[builtins.bool] has_green_instance: 实例是否处于蓝绿部署中。取值：true：是。false：否。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.str] instance_name: 实例名称。
        :param pulumi.Input[builtins.str] instance_status: 实例状态。
        :param pulumi.Input[builtins.str] instance_type: 实例类型。取值：DoubleNode，双节点类型。MultiNode，多节点类型。
        :param pulumi.Input[builtins.str] lower_case_table_names: 表名是否区分大小写，默认取值为 true。取值：false：表名被存储成固定且表名称大小写敏感。true：表名将被存储成小写且表名称大小写不敏感。
        :param pulumi.Input[Union['InstanceMaintenanceWindowArgs', 'InstanceMaintenanceWindowArgsDict']] maintenance_window: 在创建实例时指定实例的可维护时间段。该字段为可选，不设置时默认为一周内每一天的 UTC18:00Z-21:59Z（即北京时间 02:00-05:59）。
        :param pulumi.Input[builtins.str] master_instance_id: 主实例的 ID。
        :param pulumi.Input[builtins.str] master_instance_name: 主实例的名称。
        :param pulumi.Input[builtins.int] memory: 内存大小。单位：GB。
        :param pulumi.Input[builtins.float] node_cpu_used_percentage: 实例主节点 CPU 使用率近一分钟的平均值。
        :param pulumi.Input[builtins.float] node_memory_used_percentage: 实例主节点内存使用率近一分钟的平均值。
        :param pulumi.Input[builtins.str] node_number: 节点数量。
        :param pulumi.Input[builtins.float] node_space_used_percentage: 实例主节点磁盘使用率近一分钟的平均值。
        :param pulumi.Input[builtins.str] node_spec: 节点规格。
        :param pulumi.Input[builtins.int] port: 默认终端的私网端口。端口号的取值范围为 1000~65534，默认值为 3306。创建新的连接终端或开启新地址时，将使用默认终端的私网端口实时配置为默认端口。
        :param pulumi.Input[builtins.str] project_name: 所属项目。
        :param pulumi.Input[Union['InstanceProxyDetailArgs', 'InstanceProxyDetailArgsDict']] proxy_detail: proxy信息
        :param pulumi.Input[builtins.int] storage_audit_log_size: 实例存储空间中审计日志使用的空间。
        :param pulumi.Input[builtins.int] storage_bin_log_size: 实例存储空间中 Binlog 使用的空间。
        :param pulumi.Input[builtins.int] storage_data_size: 实例存储空间中数据使用的空间。
        :param pulumi.Input[builtins.int] storage_error_log_size: 实例存储空间中错误日志使用的空间。
        :param pulumi.Input[builtins.int] storage_log_size: 实例存储空间中日志使用的空间。
        :param pulumi.Input[builtins.int] storage_slow_log_size: 实例存储空间中慢日志使用的空间。
        :param pulumi.Input[builtins.int] storage_space: 实例总存储空间。单位为 GB。
        :param pulumi.Input[builtins.str] storage_type: 实例的存储类型。取值范围：LocalSSD：本地盘。CloudESSD*FlexPL：FlexPL 云盘。CloudESSD*PL0：PL0 云盘。
        :param pulumi.Input[builtins.float] storage_use: 实例已使用用存储空间，单位为 GB。
        :param pulumi.Input[builtins.str] subnet_id: 子网 ID。
        :param pulumi.Input[builtins.str] super_account_name: 高权限账号名称。不传此参数默认不创建高权限账号。
        :param pulumi.Input[builtins.str] super_account_password: 高权限账号的密码。密码规则如下：长度为 8~32 个字符。由大写字母、小写字母、数字、特殊字符中的至少三种组成。特殊字符为 !@#$%^&*()_+-=,.&?|/。
        :param pulumi.Input[builtins.str] sync_mode: 数据同步方式：SemiSync：半同步。Async：异步。
        :param pulumi.Input[builtins.str] time_zone: 时区。
        :param pulumi.Input[builtins.str] updated_time: 实例更新本地时间。
        :param pulumi.Input[builtins.int] vcpu: CPU 大小。例如：1 表示 1U。
        :param pulumi.Input[builtins.str] vpc_id: 专有网络（VPC） ID。
        :param pulumi.Input[builtins.str] zone_id: 实例主节点所在可用区。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] zone_ids: 实例各节点所在的可用区列表。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InstanceState.__new__(_InstanceState)

        __props__.__dict__["address_objects"] = address_objects
        __props__.__dict__["allow_list_ids"] = allow_list_ids
        __props__.__dict__["allow_list_version"] = allow_list_version
        __props__.__dict__["auto_storage_scaling_config"] = auto_storage_scaling_config
        __props__.__dict__["auto_upgrade_minor_version"] = auto_upgrade_minor_version
        __props__.__dict__["backup_audit_log_size"] = backup_audit_log_size
        __props__.__dict__["backup_bin_log_size"] = backup_bin_log_size
        __props__.__dict__["backup_data_size"] = backup_data_size
        __props__.__dict__["backup_error_log_size"] = backup_error_log_size
        __props__.__dict__["backup_free_quota_size"] = backup_free_quota_size
        __props__.__dict__["backup_log_size"] = backup_log_size
        __props__.__dict__["backup_slow_log_size"] = backup_slow_log_size
        __props__.__dict__["backup_use"] = backup_use
        __props__.__dict__["basic_backup_binlog_size"] = basic_backup_binlog_size
        __props__.__dict__["basic_backup_data_size"] = basic_backup_data_size
        __props__.__dict__["charge_detail"] = charge_detail
        __props__.__dict__["cpu_num"] = cpu_num
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["current_kernel_version"] = current_kernel_version
        __props__.__dict__["db_engine_version"] = db_engine_version
        __props__.__dict__["db_param_group_id"] = db_param_group_id
        __props__.__dict__["db_time_zone"] = db_time_zone
        __props__.__dict__["deletion_protection"] = deletion_protection
        __props__.__dict__["disaster_recovery_instances"] = disaster_recovery_instances
        __props__.__dict__["dr_dts_task_id"] = dr_dts_task_id
        __props__.__dict__["dr_dts_task_name"] = dr_dts_task_name
        __props__.__dict__["dr_dts_task_status"] = dr_dts_task_status
        __props__.__dict__["dr_seconds_behind_master"] = dr_seconds_behind_master
        __props__.__dict__["endpoints"] = endpoints
        __props__.__dict__["global_read_only"] = global_read_only
        __props__.__dict__["has_disaster_recovery_instances"] = has_disaster_recovery_instances
        __props__.__dict__["has_green_instance"] = has_green_instance
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["instance_name"] = instance_name
        __props__.__dict__["instance_status"] = instance_status
        __props__.__dict__["instance_type"] = instance_type
        __props__.__dict__["lower_case_table_names"] = lower_case_table_names
        __props__.__dict__["maintenance_window"] = maintenance_window
        __props__.__dict__["master_instance_id"] = master_instance_id
        __props__.__dict__["master_instance_name"] = master_instance_name
        __props__.__dict__["memory"] = memory
        __props__.__dict__["node_cpu_used_percentage"] = node_cpu_used_percentage
        __props__.__dict__["node_memory_used_percentage"] = node_memory_used_percentage
        __props__.__dict__["node_number"] = node_number
        __props__.__dict__["node_space_used_percentage"] = node_space_used_percentage
        __props__.__dict__["node_spec"] = node_spec
        __props__.__dict__["nodes"] = nodes
        __props__.__dict__["port"] = port
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["proxy_detail"] = proxy_detail
        __props__.__dict__["storage_audit_log_size"] = storage_audit_log_size
        __props__.__dict__["storage_bin_log_size"] = storage_bin_log_size
        __props__.__dict__["storage_data_size"] = storage_data_size
        __props__.__dict__["storage_error_log_size"] = storage_error_log_size
        __props__.__dict__["storage_log_size"] = storage_log_size
        __props__.__dict__["storage_slow_log_size"] = storage_slow_log_size
        __props__.__dict__["storage_space"] = storage_space
        __props__.__dict__["storage_type"] = storage_type
        __props__.__dict__["storage_use"] = storage_use
        __props__.__dict__["subnet_id"] = subnet_id
        __props__.__dict__["super_account_name"] = super_account_name
        __props__.__dict__["super_account_password"] = super_account_password
        __props__.__dict__["sync_mode"] = sync_mode
        __props__.__dict__["tags"] = tags
        __props__.__dict__["time_zone"] = time_zone
        __props__.__dict__["updated_time"] = updated_time
        __props__.__dict__["vcpu"] = vcpu
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["zone_id"] = zone_id
        __props__.__dict__["zone_ids"] = zone_ids
        return Instance(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="addressObjects")
    def address_objects(self) -> pulumi.Output[Sequence['outputs.InstanceAddressObject']]:
        return pulumi.get(self, "address_objects")

    @property
    @pulumi.getter(name="allowListIds")
    def allow_list_ids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        白名单 ID。如需绑定多个白名单，白名单 ID 用英文逗号（,）分隔。一个实例最多可绑定 100 个白名单。
        """
        return pulumi.get(self, "allow_list_ids")

    @property
    @pulumi.getter(name="allowListVersion")
    def allow_list_version(self) -> pulumi.Output[builtins.str]:
        """
        白名单版本。
        """
        return pulumi.get(self, "allow_list_version")

    @property
    @pulumi.getter(name="autoStorageScalingConfig")
    def auto_storage_scaling_config(self) -> pulumi.Output['outputs.InstanceAutoStorageScalingConfig']:
        """
        自动扩容配置。
        """
        return pulumi.get(self, "auto_storage_scaling_config")

    @property
    @pulumi.getter(name="autoUpgradeMinorVersion")
    def auto_upgrade_minor_version(self) -> pulumi.Output[builtins.str]:
        """
        实例内核小版本的升级策略。取值：Auto：自动升级。Manual：手动升级。
        """
        return pulumi.get(self, "auto_upgrade_minor_version")

    @property
    @pulumi.getter(name="backupAuditLogSize")
    def backup_audit_log_size(self) -> pulumi.Output[builtins.int]:
        """
        备份中审计日志使用的空间。
        """
        return pulumi.get(self, "backup_audit_log_size")

    @property
    @pulumi.getter(name="backupBinLogSize")
    def backup_bin_log_size(self) -> pulumi.Output[builtins.int]:
        """
        备份中 Binlog 日志使用的空间。
        """
        return pulumi.get(self, "backup_bin_log_size")

    @property
    @pulumi.getter(name="backupDataSize")
    def backup_data_size(self) -> pulumi.Output[builtins.int]:
        """
        备份中数据使用的空间。
        """
        return pulumi.get(self, "backup_data_size")

    @property
    @pulumi.getter(name="backupErrorLogSize")
    def backup_error_log_size(self) -> pulumi.Output[builtins.int]:
        """
        备份中错误日志使用的空间。
        """
        return pulumi.get(self, "backup_error_log_size")

    @property
    @pulumi.getter(name="backupFreeQuotaSize")
    def backup_free_quota_size(self) -> pulumi.Output[builtins.int]:
        """
        免费的备份存储空间，单位为 GB。
        """
        return pulumi.get(self, "backup_free_quota_size")

    @property
    @pulumi.getter(name="backupLogSize")
    def backup_log_size(self) -> pulumi.Output[builtins.int]:
        """
        备份中日志使用的空间。
        """
        return pulumi.get(self, "backup_log_size")

    @property
    @pulumi.getter(name="backupSlowLogSize")
    def backup_slow_log_size(self) -> pulumi.Output[builtins.int]:
        """
        备份中慢日志使用的空间。
        """
        return pulumi.get(self, "backup_slow_log_size")

    @property
    @pulumi.getter(name="backupUse")
    def backup_use(self) -> pulumi.Output[builtins.float]:
        """
        实例的备份已使用的空间，单位为 GB。
        """
        return pulumi.get(self, "backup_use")

    @property
    @pulumi.getter(name="basicBackupBinlogSize")
    def basic_backup_binlog_size(self) -> pulumi.Output[builtins.int]:
        """
        基础备份中 Binlog 日志使用的空间。
        """
        return pulumi.get(self, "basic_backup_binlog_size")

    @property
    @pulumi.getter(name="basicBackupDataSize")
    def basic_backup_data_size(self) -> pulumi.Output[builtins.int]:
        """
        基础备份中数据使用的空间。
        """
        return pulumi.get(self, "basic_backup_data_size")

    @property
    @pulumi.getter(name="chargeDetail")
    def charge_detail(self) -> pulumi.Output['outputs.InstanceChargeDetail']:
        """
        付费方式。
        """
        return pulumi.get(self, "charge_detail")

    @property
    @pulumi.getter(name="cpuNum")
    def cpu_num(self) -> pulumi.Output[builtins.int]:
        """
        实例数据库代理服务的 CPU 核数。
        """
        return pulumi.get(self, "cpu_num")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        实例创建本地时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="currentKernelVersion")
    def current_kernel_version(self) -> pulumi.Output[builtins.str]:
        """
        实例的内核小版本。
        """
        return pulumi.get(self, "current_kernel_version")

    @property
    @pulumi.getter(name="dbEngineVersion")
    def db_engine_version(self) -> pulumi.Output[builtins.str]:
        """
        兼容版本。取值：MySQL*5*7：MySQL 5.7 版本。MySQL*8*0：MySQL 8.0 版本。
        """
        return pulumi.get(self, "db_engine_version")

    @property
    @pulumi.getter(name="dbParamGroupId")
    def db_param_group_id(self) -> pulumi.Output[builtins.str]:
        """
        参数模板 ID。默认值为数据库引擎版本对应的默认参数模板。
        """
        return pulumi.get(self, "db_param_group_id")

    @property
    @pulumi.getter(name="dbTimeZone")
    def db_time_zone(self) -> pulumi.Output[builtins.str]:
        """
        时区。支持 UTC -12:00 ~ +13:00。默认值为 Region 所在的 TimeZone。
        """
        return pulumi.get(self, "db_time_zone")

    @property
    @pulumi.getter(name="deletionProtection")
    def deletion_protection(self) -> pulumi.Output[builtins.str]:
        """
        是否启用实例的删除保护功能。取值：Enabled：是。Disabled：否。默认值。
        """
        return pulumi.get(self, "deletion_protection")

    @property
    @pulumi.getter(name="disasterRecoveryInstances")
    def disaster_recovery_instances(self) -> pulumi.Output[Sequence['outputs.InstanceDisasterRecoveryInstance']]:
        return pulumi.get(self, "disaster_recovery_instances")

    @property
    @pulumi.getter(name="drDtsTaskId")
    def dr_dts_task_id(self) -> pulumi.Output[builtins.str]:
        """
        主实例与灾备实例之间的数据同步链路在 DTS 数据同步任务的 ID。
        """
        return pulumi.get(self, "dr_dts_task_id")

    @property
    @pulumi.getter(name="drDtsTaskName")
    def dr_dts_task_name(self) -> pulumi.Output[builtins.str]:
        """
        主实例与灾备实例之间同步任务的名称。
        """
        return pulumi.get(self, "dr_dts_task_name")

    @property
    @pulumi.getter(name="drDtsTaskStatus")
    def dr_dts_task_status(self) -> pulumi.Output[builtins.str]:
        """
        主实例与灾备实例之间同步任务的状态。
        """
        return pulumi.get(self, "dr_dts_task_status")

    @property
    @pulumi.getter(name="drSecondsBehindMaster")
    def dr_seconds_behind_master(self) -> pulumi.Output[builtins.int]:
        """
        灾备实例与主实例之间的时延。
        """
        return pulumi.get(self, "dr_seconds_behind_master")

    @property
    @pulumi.getter
    def endpoints(self) -> pulumi.Output[Sequence['outputs.InstanceEndpoint']]:
        return pulumi.get(self, "endpoints")

    @property
    @pulumi.getter(name="globalReadOnly")
    def global_read_only(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启全局只读。取值：true：是。false：否。默认值为 false。
        """
        return pulumi.get(self, "global_read_only")

    @property
    @pulumi.getter(name="hasDisasterRecoveryInstances")
    def has_disaster_recovery_instances(self) -> pulumi.Output[builtins.bool]:
        """
        实例是否有灾备实例。取值：true：是。false：否。
        """
        return pulumi.get(self, "has_disaster_recovery_instances")

    @property
    @pulumi.getter(name="hasGreenInstance")
    def has_green_instance(self) -> pulumi.Output[builtins.bool]:
        """
        实例是否处于蓝绿部署中。取值：true：是。false：否。
        """
        return pulumi.get(self, "has_green_instance")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> pulumi.Output[builtins.str]:
        """
        实例名称。
        """
        return pulumi.get(self, "instance_name")

    @property
    @pulumi.getter(name="instanceStatus")
    def instance_status(self) -> pulumi.Output[builtins.str]:
        """
        实例状态。
        """
        return pulumi.get(self, "instance_status")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> pulumi.Output[builtins.str]:
        """
        实例类型。取值：DoubleNode，双节点类型。MultiNode，多节点类型。
        """
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter(name="lowerCaseTableNames")
    def lower_case_table_names(self) -> pulumi.Output[builtins.str]:
        """
        表名是否区分大小写，默认取值为 true。取值：false：表名被存储成固定且表名称大小写敏感。true：表名将被存储成小写且表名称大小写不敏感。
        """
        return pulumi.get(self, "lower_case_table_names")

    @property
    @pulumi.getter(name="maintenanceWindow")
    def maintenance_window(self) -> pulumi.Output['outputs.InstanceMaintenanceWindow']:
        """
        在创建实例时指定实例的可维护时间段。该字段为可选，不设置时默认为一周内每一天的 UTC18:00Z-21:59Z（即北京时间 02:00-05:59）。
        """
        return pulumi.get(self, "maintenance_window")

    @property
    @pulumi.getter(name="masterInstanceId")
    def master_instance_id(self) -> pulumi.Output[builtins.str]:
        """
        主实例的 ID。
        """
        return pulumi.get(self, "master_instance_id")

    @property
    @pulumi.getter(name="masterInstanceName")
    def master_instance_name(self) -> pulumi.Output[builtins.str]:
        """
        主实例的名称。
        """
        return pulumi.get(self, "master_instance_name")

    @property
    @pulumi.getter
    def memory(self) -> pulumi.Output[builtins.int]:
        """
        内存大小。单位：GB。
        """
        return pulumi.get(self, "memory")

    @property
    @pulumi.getter(name="nodeCpuUsedPercentage")
    def node_cpu_used_percentage(self) -> pulumi.Output[builtins.float]:
        """
        实例主节点 CPU 使用率近一分钟的平均值。
        """
        return pulumi.get(self, "node_cpu_used_percentage")

    @property
    @pulumi.getter(name="nodeMemoryUsedPercentage")
    def node_memory_used_percentage(self) -> pulumi.Output[builtins.float]:
        """
        实例主节点内存使用率近一分钟的平均值。
        """
        return pulumi.get(self, "node_memory_used_percentage")

    @property
    @pulumi.getter(name="nodeNumber")
    def node_number(self) -> pulumi.Output[builtins.str]:
        """
        节点数量。
        """
        return pulumi.get(self, "node_number")

    @property
    @pulumi.getter(name="nodeSpaceUsedPercentage")
    def node_space_used_percentage(self) -> pulumi.Output[builtins.float]:
        """
        实例主节点磁盘使用率近一分钟的平均值。
        """
        return pulumi.get(self, "node_space_used_percentage")

    @property
    @pulumi.getter(name="nodeSpec")
    def node_spec(self) -> pulumi.Output[builtins.str]:
        """
        节点规格。
        """
        return pulumi.get(self, "node_spec")

    @property
    @pulumi.getter
    def nodes(self) -> pulumi.Output[Sequence['outputs.InstanceNode']]:
        return pulumi.get(self, "nodes")

    @property
    @pulumi.getter
    def port(self) -> pulumi.Output[builtins.int]:
        """
        默认终端的私网端口。端口号的取值范围为 1000~65534，默认值为 3306。创建新的连接终端或开启新地址时，将使用默认终端的私网端口实时配置为默认端口。
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        所属项目。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="proxyDetail")
    def proxy_detail(self) -> pulumi.Output['outputs.InstanceProxyDetail']:
        """
        proxy信息
        """
        return pulumi.get(self, "proxy_detail")

    @property
    @pulumi.getter(name="storageAuditLogSize")
    def storage_audit_log_size(self) -> pulumi.Output[builtins.int]:
        """
        实例存储空间中审计日志使用的空间。
        """
        return pulumi.get(self, "storage_audit_log_size")

    @property
    @pulumi.getter(name="storageBinLogSize")
    def storage_bin_log_size(self) -> pulumi.Output[builtins.int]:
        """
        实例存储空间中 Binlog 使用的空间。
        """
        return pulumi.get(self, "storage_bin_log_size")

    @property
    @pulumi.getter(name="storageDataSize")
    def storage_data_size(self) -> pulumi.Output[builtins.int]:
        """
        实例存储空间中数据使用的空间。
        """
        return pulumi.get(self, "storage_data_size")

    @property
    @pulumi.getter(name="storageErrorLogSize")
    def storage_error_log_size(self) -> pulumi.Output[builtins.int]:
        """
        实例存储空间中错误日志使用的空间。
        """
        return pulumi.get(self, "storage_error_log_size")

    @property
    @pulumi.getter(name="storageLogSize")
    def storage_log_size(self) -> pulumi.Output[builtins.int]:
        """
        实例存储空间中日志使用的空间。
        """
        return pulumi.get(self, "storage_log_size")

    @property
    @pulumi.getter(name="storageSlowLogSize")
    def storage_slow_log_size(self) -> pulumi.Output[builtins.int]:
        """
        实例存储空间中慢日志使用的空间。
        """
        return pulumi.get(self, "storage_slow_log_size")

    @property
    @pulumi.getter(name="storageSpace")
    def storage_space(self) -> pulumi.Output[builtins.int]:
        """
        实例总存储空间。单位为 GB。
        """
        return pulumi.get(self, "storage_space")

    @property
    @pulumi.getter(name="storageType")
    def storage_type(self) -> pulumi.Output[builtins.str]:
        """
        实例的存储类型。取值范围：LocalSSD：本地盘。CloudESSD*FlexPL：FlexPL 云盘。CloudESSD*PL0：PL0 云盘。
        """
        return pulumi.get(self, "storage_type")

    @property
    @pulumi.getter(name="storageUse")
    def storage_use(self) -> pulumi.Output[builtins.float]:
        """
        实例已使用用存储空间，单位为 GB。
        """
        return pulumi.get(self, "storage_use")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Output[builtins.str]:
        """
        子网 ID。
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter(name="superAccountName")
    def super_account_name(self) -> pulumi.Output[builtins.str]:
        """
        高权限账号名称。不传此参数默认不创建高权限账号。
        """
        return pulumi.get(self, "super_account_name")

    @property
    @pulumi.getter(name="superAccountPassword")
    def super_account_password(self) -> pulumi.Output[builtins.str]:
        """
        高权限账号的密码。密码规则如下：长度为 8~32 个字符。由大写字母、小写字母、数字、特殊字符中的至少三种组成。特殊字符为 !@#$%^&*()_+-=,.&?|/。
        """
        return pulumi.get(self, "super_account_password")

    @property
    @pulumi.getter(name="syncMode")
    def sync_mode(self) -> pulumi.Output[builtins.str]:
        """
        数据同步方式：SemiSync：半同步。Async：异步。
        """
        return pulumi.get(self, "sync_mode")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.InstanceTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="timeZone")
    def time_zone(self) -> pulumi.Output[builtins.str]:
        """
        时区。
        """
        return pulumi.get(self, "time_zone")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        实例更新本地时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter
    def vcpu(self) -> pulumi.Output[builtins.int]:
        """
        CPU 大小。例如：1 表示 1U。
        """
        return pulumi.get(self, "vcpu")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[builtins.str]:
        """
        专有网络（VPC） ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Output[builtins.str]:
        """
        实例主节点所在可用区。
        """
        return pulumi.get(self, "zone_id")

    @property
    @pulumi.getter(name="zoneIds")
    def zone_ids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        实例各节点所在的可用区列表。
        """
        return pulumi.get(self, "zone_ids")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'AssumeRole',
    'Endpoints',
]

@pulumi.output_type
class AssumeRole(dict):
    def __init__(__self__, *,
                 assume_role_trn: builtins.str,
                 duration_seconds: Optional[builtins.int] = None,
                 policy: Optional[builtins.str] = None):
        """
        :param builtins.str assume_role_trn: he TRN of the role to assume.
        :param builtins.int duration_seconds: The duration of the session when making the AssumeRole call. Its value ranges from 900 to 43200(seconds), and default is 3600 seconds.
        :param builtins.str policy: A more restrictive policy when making the AssumeRole call
        """
        pulumi.set(__self__, "assume_role_trn", assume_role_trn)
        if duration_seconds is not None:
            pulumi.set(__self__, "duration_seconds", duration_seconds)
        if policy is not None:
            pulumi.set(__self__, "policy", policy)

    @property
    @pulumi.getter(name="assumeRoleTrn")
    def assume_role_trn(self) -> builtins.str:
        """
        he TRN of the role to assume.
        """
        return pulumi.get(self, "assume_role_trn")

    @property
    @pulumi.getter(name="durationSeconds")
    def duration_seconds(self) -> Optional[builtins.int]:
        """
        The duration of the session when making the AssumeRole call. Its value ranges from 900 to 43200(seconds), and default is 3600 seconds.
        """
        return pulumi.get(self, "duration_seconds")

    @property
    @pulumi.getter
    def policy(self) -> Optional[builtins.str]:
        """
        A more restrictive policy when making the AssumeRole call
        """
        return pulumi.get(self, "policy")


@pulumi.output_type
class Endpoints(dict):
    def __init__(__self__, *,
                 cloudcontrolapi: Optional[builtins.str] = None,
                 sts: Optional[builtins.str] = None):
        """
        :param builtins.str cloudcontrolapi: Use this to override the default Cloud Control API service endpoint URL
        :param builtins.str sts: Use this to override the default STS service endpoint URL
        """
        if cloudcontrolapi is not None:
            pulumi.set(__self__, "cloudcontrolapi", cloudcontrolapi)
        if sts is not None:
            pulumi.set(__self__, "sts", sts)

    @property
    @pulumi.getter
    def cloudcontrolapi(self) -> Optional[builtins.str]:
        """
        Use this to override the default Cloud Control API service endpoint URL
        """
        return pulumi.get(self, "cloudcontrolapi")

    @property
    @pulumi.getter
    def sts(self) -> Optional[builtins.str]:
        """
        Use this to override the default STS service endpoint URL
        """
        return pulumi.get(self, "sts")


